@@ -2,6 +2,7 @@
 import json
 
 from requests import Session, Request
+from requests.adapters import HTTPAdapter
 import requests
 from serverdensity import __version__
 from serverdensity.wrapper.exceptions import HttpError
@@ -115,7 +116,6 @@ class ApiClient(object):
     def _make_request(self, method, url, data=None, params=None, **kwargs):
         if params:
             self.params.update(params)
-            params = self._stringify_dict_list(params)
         if kwargs.get('headers'):
             self.headers.update(kwargs['headers'])
         if data:
@@ -126,6 +126,7 @@ class ApiClient(object):
         prepped = req.prepare()
 
         try:
+            self._session.mount('https://', HTTPAdapter(max_retries=3))
             response = self._session.send(prepped, timeout=self.timeout)
             if response.status_code > 299:
                 if 'message' in str(response.content):
